@@ -1,5 +1,5 @@
 package ExtUtils::Builder::Profile::Perl;
-$ExtUtils::Builder::Profile::Perl::VERSION = '0.025';
+$ExtUtils::Builder::Profile::Perl::VERSION = '0.026';
 use strict;
 use warnings;
 
@@ -45,6 +45,10 @@ sub process_linker {
 		$linker->add_option_filter(sub {
 			my ($self, $from, $to, %opts) = @_;
 			$opts{dl_name} //= $opts{module_name} if $opts{module_name};
+			$opts{dl_file} //= do {
+				(my $short = $opts{dl_name}) =~ s/.*:://;
+				catdir(dirname($from), "$short.def");
+			};
 			return ($from, $to, %opts);
 		});
 	}
@@ -81,7 +85,7 @@ ExtUtils::Builder::Profile::Perl - A profile for compiling and linking against p
 
 =head1 VERSION
 
-version 0.025
+version 0.026
 
 =head1 SYNOPSIS
 
